@@ -28,7 +28,8 @@ class CollectionRequestHandler(_RequestHandlerMixin,
          ORDER BY link_type ASC""")
 
     POST_SQL = re.sub(r'\s+', ' ', """\
-        INSERT INTO v1.project_link_types (link_type, created_by, icon_class)
+        INSERT INTO v1.project_link_types
+                    (link_type, created_by, icon_class)
              VALUES (%(link_type)s, %(username)s, %(icon_class)s)
           RETURNING id""")
 
